# aiogoogletrans fork

This is a fork of [aiogoogletrans](https://github.com/katlol/aiogoogletrans) which is a fork of [googletrans](https://github.com/ssut/py-googletrans) with minor changes and renamed to granslate? no? :)

```
for further info and credits, lookup the original repo. Thanks :)
```

Available on pypi as granslate (`pip install granslate`)<br>
consider using the original one instead of mine. thanks :)

(name inspired from gmail -> email)
